@@ -589,3 +589,6 @@ def _typecheckingstub__0ee573dc76bc92a12e354645f16bbb841f2b98ecbfd3955fb5a5fc536
 ) -> None:
     """Type checking stubs"""
     pass
+
+for cls in [IDomainProps, IDomainRepositoryProps]:
+    typing.cast(typing.Any, cls).__protocol_attrs__ = typing.cast(typing.Any, cls).__protocol_attrs__ - set(['__jsii_proxy_class__', '__jsii_type__'])
